@@ -1,7 +1,7 @@
 correct.F<-function(P)
 {
  if(!is.numeric(P) || (P<0 || P>=100.0))
-      stop("invalid input parameter(s) specification: check percent P")
+      stop("Invalid input parameter specification: check percentage P")
 
  1/(1-P)
  }
\ No newline at end of file
